summaryrefslogtreecommitdiffstats
path: root/generic/tkStyle.c
diff options
context:
space:
mode:
authorjan.nijtmans <nijtmans@users.sourceforge.net>2013-02-01 14:30:07 (GMT)
committerjan.nijtmans <nijtmans@users.sourceforge.net>2013-02-01 14:30:07 (GMT)
commit36cc0029458ead72be711c8c402f55a4fd26edd3 (patch)
tree9d78414244a27069e5362313cf542baba8dfefb1 /generic/tkStyle.c
parentc122ab6dc1e84c1b07be22f6b1b3983df7268a68 (diff)
parent5f84e8bb5604b44e2682c85e6bf8724deb5c3257 (diff)
downloadtk-36cc0029458ead72be711c8c402f55a4fd26edd3.zip
tk-36cc0029458ead72be711c8c402f55a4fd26edd3.tar.gz
tk-36cc0029458ead72be711c8c402f55a4fd26edd3.tar.bz2
Use internalRep.twoPtrValue.ptr1 in stead of internalRep.otherValuePtr everywhere.
Change some internal "length" variables from type int to type size_t, so it could handle bigger string sizes (for "novem")
Diffstat (limited to 'generic/tkStyle.c')
-rw-r--r--generic/tkStyle.c16
1 files changed, 8 insertions, 8 deletions
diff --git a/generic/tkStyle.c b/generic/tkStyle.c
index d5e1407..e7401df 100644
--- a/generic/tkStyle.c
+++ b/generic/tkStyle.c
@@ -146,8 +146,8 @@ static int SetStyleFromAny(Tcl_Interp *interp, Tcl_Obj *objPtr);
/*
* The following structure defines the implementation of the "style" Tcl
* object, used for drawing. The internalRep.otherValuePtr field of each style
* object points to the Style structure for the stylefont, or NULL.
*/
static const Tcl_ObjType styleObjType = {
@@ -1410,7 +1410,7 @@ Tk_AllocStyleFromObj(
if (objPtr->typePtr != &styleObjType) {
SetStyleFromAny(interp, objPtr);
}
- stylePtr = objPtr->internalRep.otherValuePtr;
+ stylePtr = objPtr->internalRep.twoPtrValue.ptr1;
return (Tk_Style) stylePtr;
}
@@ -1442,7 +1442,7 @@ Tk_GetStyleFromObj(
SetStyleFromAny(NULL, objPtr);
}
- return objPtr->internalRep.otherValuePtr;
+ return objPtr->internalRep.twoPtrValue.ptr1;
}
/*
@@ -1497,7 +1497,7 @@ SetStyleFromAny(
}
objPtr->typePtr = &styleObjType;
- objPtr->internalRep.otherValuePtr = Tk_GetStyle(interp, name);
+ objPtr->internalRep.twoPtrValue.ptr1 = Tk_GetStyle(interp, name);
return TCL_OK;
}
@@ -1520,7 +1520,7 @@ static void
FreeStyleObjProc(
Tcl_Obj *objPtr) /* The object we are releasing. */
{
- objPtr->internalRep.otherValuePtr = NULL;
+ objPtr->internalRep.twoPtrValue.ptr1 = NULL;
objPtr->typePtr = NULL;
}
@@ -1541,8 +1541,8 @@ DupStyleObjProc(
Tcl_Obj *dupObjPtr) /* The object we are copying to. */
{
dupObjPtr->typePtr = srcObjPtr->typePtr;
- dupObjPtr->internalRep.otherValuePtr =
- srcObjPtr->internalRep.otherValuePtr;
+ dupObjPtr->internalRep.twoPtrValue.ptr1 =
+ srcObjPtr->internalRep.twoPtrValue.ptr1;
}
/*
@@ -146,8 +146,8 @@ static int SetStyleFromAny(Tcl_Interp *interp, Tcl_Obj *objPtr);
/*
* The following structure defines the implementation of the "style" Tcl
- * object, used for drawing. The internalRep.otherValuePtr field of each style
- * object points to the Style structure for the stylefont, or NULL.
+ * object, used for drawing. The internalRep.twoPtrValue.ptr1 field of each
+ * style object points to the Style structure for the stylefont, or NULL.
*/
static const Tcl_ObjType styleObjType = {